@@ -6,8 +6,8 @@ Information about the current version of the py-package-template package.
 """
 
 __title__ = 'blazer'
-__description__ = 'An HPC abstraction over MPI that uses pipes and pydash primitives.'
-__version__ = '0.1.17'
+__description__ = 'An HPC abstraction over MPI that uses pipes and pydash primitives for composable super-computing.'
+__version__ = '0.1.18'
 __author__ = 'Darren Govoni'
 __author_email__ = 'darren@ontrenet.com'
 __license__ = 'CC0-1.0 License'
